@@ -69,7 +69,7 @@ def phrase_build(number, noun_forms=None, prefix_forms=None, grouping_symbol='`'
     noun_forms : list
         Declensions of noun
     prefix_forms : list
-        Declensions of prefix word
+        Declensions of prefix word, mute if False
     grouping_symbol : str
         Digit grouping symbol
 
@@ -84,6 +84,9 @@ def phrase_build(number, noun_forms=None, prefix_forms=None, grouping_symbol='`'
     >>> phrase_build(42)
     Опубликованы 42 новости
 
+    >>> phrase_build(15, ['сияющих звезд', 'сияющая звезда', 'сияющие звезды'], False)
+    15 сияющих звезд
+
     >>> phrase_build(31, ['китов', 'кит', 'кита'], ['Спасены', 'Спасен'])
     Спасен 31 кит
 
@@ -92,6 +95,8 @@ def phrase_build(number, noun_forms=None, prefix_forms=None, grouping_symbol='`'
 
     if prefix_forms is None:
         prefix_forms = ['Опубликованы', 'Опубликована']
+    elif prefix_forms == False:
+        prefix_forms = ['','']
 
     if noun_forms is None:
         noun_forms = ['новостей', 'новость', 'новости']
@@ -167,7 +172,7 @@ def read_urls_contents(urls_list, max_workers=10, session=None, parser=None, enc
         future_load_csv = {executor.submit(url_loader, url, session, timeout, encoding): url for url in urls_list}
         for i, future in enumerate(pool.as_completed(future_load_csv)):
             if not mute:
-                print(f"URLs list download: {PROGRESS_WHEEL[i%8]} {i/len(urls_list)*.994:.0%}",end='\r',flush=True)
+                print(f"URLs list download: {PROGRESS_WHEEL[i%8]} {i/len(urls_list)*.995:<50.0%}",end='\r',flush=True)
             url = future_load_csv[future]
             try:
                 buf.write(parser(future.result()))
@@ -177,7 +182,8 @@ def read_urls_contents(urls_list, max_workers=10, session=None, parser=None, enc
                 else:
                     error_page_output.write(f'Download error:\n{url}|{exc}')
     buf.seek(0)
-    print("URLs list download:   100%")
+    if not mute:
+        print("URLs list download:   100%")
     return buf
 
 
